=======================
ReactiveX eXtensions
=======================

.. image:: https://img.shields.io/pypi/v/rxx.svg
    :target: https://pypi.org/project/rxx/
    :alt: PyPI

.. image:: https://github.com/maki-nage/rxx/workflows/Python%20package/badge.svg
    :target: https://github.com/maki-nage/rxx/actions?query=workflow%3A%22Python+package%22
    :alt: Github WorkFlows

.. image:: https://coveralls.io/repos/github/maki-nage/rxx/badge.svg?branch=master
    :target: https://coveralls.io/github/maki-nage/rxx?branch=master
    :alt: Code Coverage

.. image:: https://github.com/maki-nage/rxx/raw/master/asset/apis_read.svg
    :target: https://www.makinage.org/doc/rxx/latest/index.html
    :alt: Documentation


Additional ReactiveX operators.

Get Started
============

Installation
=============

Rxx is available on PyPi and can be installed with pip:

.. code:: console

    python3 -m pip install rxx
